outputs

package
v0.28.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 31, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Package outputs provides the ability for Vela to manipulate and manage a the outputs map during a build.

Usage:

import "github.com/go-vela/worker/internal/outputs"

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Process added in v0.28.0

func Process(c *pipeline.Container, outputs, maskedOutputs map[string]string)

Process adds the outputs to the container environment after sanitizing them and replacing $REFERENCES already in the environment. It also adds masked outputs to container secrets for masking in logs.

Types

This section is empty.

Jump to